==> ChimeraX-0.1.6-cp311-cp311-macosx_11_0_universal2.whl: chimerax/atomic_lib/include/atomstruct/session.h <==
// vi: set expandtab ts=4 sw=4:

/*
 * === UCSF ChimeraX Copyright ===
 * Copyright 2022 Regents of the University of California. All rights reserved.
 * The ChimeraX application is provided pursuant to the ChimeraX license
 * agreement, which covers academic and commercial uses. For more details, see
 * <http://www.rbvi.ucsf.edu/chimerax/docs/licensing.html>
 *
 * This particular file is part of the ChimeraX library. You can also
 * redistribute and/or modify it under the terms of the GNU Lesser General
 * Public License version 2.1 as published by the Free Software Foundation.
 * For more details, see
 * <https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html>
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. ADDITIONAL LIABILITY
 * LIMITATIONS ARE DESCRIBED IN THE GNU LESSER GENERAL PUBLIC LICENSE
 * VERSION 2.1
 *
 * This notice must be embedded in or attached to all copies, including partial
 * copies, of the software or any revisions or derivations thereof.
 * === UCSF ChimeraX Copyright ===
 */

#ifndef atomstruct_session
#define atomstruct_session

// DON'T FORGET TO UPDATE Structure::copy() AS WELL!!
// ALSO: bump maxSessionVersion in atomic's bundle_info.xml
//
// Each class's SESSION_NUM... methods yield the number of those types that don't vary on
// a per-instance basis and are directly saved/restored by that class and not by a contained
// class such as Rgba.
#define CURRENT_SESSION_VERSION 18

#endif  // atomstruct_session

==> ChimeraX-0.1.8-cp311-cp311-macosx_10_15_universal2.whl: chimerax/atomic_lib/include/atomstruct/session.h <==
// vi: set expandtab ts=4 sw=4:

/*
 * === UCSF ChimeraX Copyright ===
 * Copyright 2022 Regents of the University of California. All rights reserved.
 * The ChimeraX application is provided pursuant to the ChimeraX license
 * agreement, which covers academic and commercial uses. For more details, see
 * <http://www.rbvi.ucsf.edu/chimerax/docs/licensing.html>
 *
 * This particular file is part of the ChimeraX library. You can also
 * redistribute and/or modify it under the terms of the GNU Lesser General
 * Public License version 2.1 as published by the Free Software Foundation.
 * For more details, see
 * <https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html>
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. ADDITIONAL LIABILITY
 * LIMITATIONS ARE DESCRIBED IN THE GNU LESSER GENERAL PUBLIC LICENSE
 * VERSION 2.1
 *
 * This notice must be embedded in or attached to all copies, including partial
 * copies, of the software or any revisions or derivations thereof.
 * === UCSF ChimeraX Copyright ===
 */

#ifndef atomstruct_session
#define atomstruct_session

// DON'T FORGET TO UPDATE Structure::copy() AS WELL!!
// ALSO: bump maxSessionVersion in atomic's bundle_info.xml and STRUCTURE_STATE_VERSION in structure.py
//
// Each class's SESSION_NUM... methods yield the number of those types that don't vary on
// a per-instance basis and are directly saved/restored by that class and not by a contained
// class such as Rgba.
#define CURRENT_SESSION_VERSION 21

#endif  // atomstruct_session
